@@ -707,7 +707,7 @@ MainWindow::findInfo (const QString &strNumber, GVContactInfo &info)
 
     QString strTrunc = strNumber;
     GVAccess::simplify_number (strTrunc, false);
-    strTrunc.remove (' ');
+    strTrunc.remove(' ').remove('+');
 
     CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
     if (!dbMain.getContactFromNumber (strNumber, info)) {
@@ -901,6 +901,11 @@ MainWindow::onSendTextWithoutData (const QStringList &arrNumbers)
 
         dlgSMS.addSMSEntry (entry);
     }
+
+    if (dlgSMS.isHidden ())
+    {
+        dlgSMS.show ();
+    }
 }//MainWindow::onSendTextWithoutData
 
 void
